==> haskell-wreq-0.5.2.1-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wreq
version: 0.5.2.1
id: wreq-0.5.2.1-AyDFa3m2qB156M6RjllY4Q
key: wreq-0.5.2.1-AyDFa3m2qB156M6RjllY4Q
license: BSD-3-Clause
copyright: 2014 Bryan O'\''Sullivan
maintainer: bos@serpentine.com
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/wreq
synopsis: An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
    http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
    cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
    schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package
category: Web
abi: 095ee0865b853b44ac492166c1fd75a5
exposed: True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types
hidden-modules: Network.Wreq.Internal Network.Wreq.Internal.AWS
                Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
                Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
                Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq
import-dirs: /usr/lib/ghc-8.4.3/site-local/wreq-0.5.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/wreq-0.5.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wreq-0.5.2.1
hs-libraries: HSwreq-0.5.2.1-AyDFa3m2qB156M6RjllY4Q
depends:
    psqueues-0.2.7.0-FGOfpjoyYkg9RnbVvoYBTi
    aeson-1.3.1.1-ArWpZy1DbZ6Lxt3YgJqPBO
    attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ
    authenticate-oauth-1.6-GDVATr2PHzcKWehHMUAfP base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 cryptonite-0.25-HG1e5oKlC351RQKtUSxglv
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf ghc-prim-0.5.2.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    http-client-0.5.13-GyLA8HATX9cHiBKliNKWxB
    http-client-tls-0.3.5.3-EfA9ZJY3lxYAntfw9R6ptV
    http-types-0.12.1-9rf2Bc0mANC4pe1MDcYyOl
    lens-4.16.1-CI8r7lJC6eG7FYMQb0SOhg
    lens-aeson-1.0.2-KiIWbF3jpZi3slmNsDCGEB
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
    mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4
    time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
    template-haskell-2.13.0.0 text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
abi-depends: psqueues-0.2.7.0-FGOfpjoyYkg9RnbVvoYBTi=37a2debe3bd2c6fbef3d15752201d7da
             aeson-1.3.1.1-ArWpZy1DbZ6Lxt3YgJqPBO=63ce14baf2a7c28abbc692d9e7dd92cc
             attoparsec-0.13.2.2-3UshHsIb0S9BZJuxZmJPoQ=b6c55238d5ca948928baa2c3b9c37177
             authenticate-oauth-1.6-GDVATr2PHzcKWehHMUAfP=6964202a06015fbb1996811043b2f244
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=bba358ad6d6aaa259e18cb7e07ede79c
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptonite-0.25-HG1e5oKlC351RQKtUSxglv=5008fcc70bd425af43dd504f7310f344
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             http-client-0.5.13-GyLA8HATX9cHiBKliNKWxB=c70ea065b1fde639c4b7cb3ed9f544b5
             http-client-tls-0.3.5.3-EfA9ZJY3lxYAntfw9R6ptV=71ad80d48ab3f56929ec297177737927
             http-types-0.12.1-9rf2Bc0mANC4pe1MDcYyOl=f077e3c0d9d6c05be2dfc7d9c3ae67ad
             lens-4.16.1-CI8r7lJC6eG7FYMQb0SOhg=b69b1df8d1b879a48e7570c642b41b72
             lens-aeson-1.0.2-KiIWbF3jpZi3slmNsDCGEB=202a3ca0b37d60b844367bf600c5f74d
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=ebd23a14864af42a4155f70cf1514d40
             mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4=6bc38bc2f3d7f7e0258709c15024ed43
             time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb=87c3e02b63d10c8290e7f2f894b7a341
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
haddock-interfaces: /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html: /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wreq-0.5.2.1-45-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wreq
version: 0.5.2.1
id: wreq-0.5.2.1-GE2MCnS1q5d1xCh3JHYMvW
key: wreq-0.5.2.1-GE2MCnS1q5d1xCh3JHYMvW
license: BSD-3-Clause
copyright: 2014 Bryan O'\''Sullivan
maintainer: bos@serpentine.com
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/wreq
synopsis: An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
    http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
    cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
    schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package
category: Web
abi: c603ae9dd3cc473c17c656b1814c3aa4
exposed: True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types
hidden-modules: Network.Wreq.Internal Network.Wreq.Internal.AWS
                Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
                Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
                Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq
import-dirs: /usr/lib/ghc-8.4.3/site-local/wreq-0.5.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/wreq-0.5.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wreq-0.5.2.1
hs-libraries: HSwreq-0.5.2.1-GE2MCnS1q5d1xCh3JHYMvW
depends:
    psqueues-0.2.7.0-JGyeYJ6SZYn26QT6Qw59vy
    aeson-1.3.1.1-AXgHZuIctxnFM9yj6fGKmb
    attoparsec-0.13.2.2-7kmhoL5l3stA3NDsk1DtWk
    authenticate-oauth-1.6-G3s0ViDh6SsLcQFi1IIEa0 base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf ghc-prim-0.5.2.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    http-client-0.5.13.1-3toxJfBE59PAIZbOjn1vZq
    http-client-tls-0.3.5.3-pT5ciJvDczJ2AiYpmJrKE
    http-types-0.12.1-86SMkuMxdGmiSnGNxpMRm
    lens-4.17-J6MEyQHUHDfHg3h2L7iPl8
    lens-aeson-1.0.2-KrxVg6yRtAf1JyiPVGuKc8
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4
    time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
    template-haskell-2.13.0.0 text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
abi-depends: psqueues-0.2.7.0-JGyeYJ6SZYn26QT6Qw59vy=af5b8b26e5e8b1d52d882ddb389ef74a
             aeson-1.3.1.1-AXgHZuIctxnFM9yj6fGKmb=1a0b471e50c15f7e577ddfc096bd1a75
             attoparsec-0.13.2.2-7kmhoL5l3stA3NDsk1DtWk=825d47e693044b92530553d85386444f
             authenticate-oauth-1.6-G3s0ViDh6SsLcQFi1IIEa0=bd74bf9ed4a4118cc657da0c4b5b1ee0
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=bba358ad6d6aaa259e18cb7e07ede79c
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             http-client-0.5.13.1-3toxJfBE59PAIZbOjn1vZq=ebf8ac947014b4c7473903f8a577adce
             http-client-tls-0.3.5.3-pT5ciJvDczJ2AiYpmJrKE=1778621b7ca173f9d5cc7db4a87ec886
             http-types-0.12.1-86SMkuMxdGmiSnGNxpMRm=78d489696f728b72c10468a4eac9f283
             lens-4.17-J6MEyQHUHDfHg3h2L7iPl8=b147b2d680434e140447afb3c145588f
             lens-aeson-1.0.2-KrxVg6yRtAf1JyiPVGuKc8=9d853d8cf5dc39065cc11e053cd6b4dd
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
             mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4=1f2d3d0537de744febdcb254f1bfc8b9
             time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb=87c3e02b63d10c8290e7f2f894b7a341
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
haddock-interfaces: /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html: /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
